@@ -67,6 +67,7 @@
 #  include "chxj_mysql.h"
 #endif
 #include "chxj_serf.h"
+#include "chxj_add_device_env.h"
 
 
 #define CHXJ_VERSION_PREFIX PACKAGE_NAME "/"
@@ -268,6 +269,8 @@ chxj_headers_fixup(request_rec *r)
     }
   }
 
+  chxj_add_device_env(r, spec);
+
   DBG(r, "REQ[%X] end chxj_headers_fixup()", (unsigned int)(apr_size_t)r);
 
   return DECLINED;
