@@ -34,6 +34,11 @@ qs_parse_tag(Doc *doc, const char *s, int len)
   int    ll;
   int    next_point;
 
+  if (! doc) {
+    QX_LOGGER_FATAL("runtime exception: qs_parse_tag(): doc is null");
+    return NULL;
+  }
+
   sv_s = sp = (char *)s;
   ll         = len;
   next_point = 0;
@@ -46,7 +51,11 @@ qs_parse_tag(Doc *doc, const char *s, int len)
    */
   tag_name = (char *)s_get_tag_name(doc, ++s, --ll);
 
-  node = (Node*)qs_new_tag(doc);
+  node = (Node *)qs_new_tag(doc);
+  if (! node) {
+    QX_LOGGER_DEBUG("runtime exception: qs_parse_tag(): Out of memory.");
+    return NULL;
+  }
   node->name = tag_name;
   node->otext = apr_palloc(doc->pool,len+2);
   memset(node->otext, 0, len+2);
@@ -68,7 +77,7 @@ qs_parse_tag(Doc *doc, const char *s, int len)
     sp += next_point;
     ll -= next_point;
     QX_LOGGER_DEBUG_INT(sp, ll);
-    node = (Node*)qs_add_attr(doc,node, attr);
+    node = (Node *)qs_add_attr(doc,node, attr);
   }
 
   if (sv_s[len-1] == '/') {
@@ -85,13 +94,13 @@ qs_parse_tag(Doc *doc, const char *s, int len)
 
 
 
-static char* 
-s_get_tag_name(Doc* doc, const char* s, int len)  
+static char * 
+s_get_tag_name(Doc *doc, const char *s, int len)  
 {
   int ii;
   int sp;
   int size;
-  char* return_value = NULL;
+  char *return_value = NULL;
 
   /* ignore space. */
   for (ii = 0; ii < len; ii++) {
@@ -108,7 +117,7 @@ s_get_tag_name(Doc* doc, const char* s, int len)
 
   size = ii-sp;
 
-  return_value = (char*)apr_palloc(doc->pool, size+1);
+  return_value = (char *)apr_palloc(doc->pool, size+1);
 
   memset(return_value, 0, size+1);
   memcpy(return_value, &s[sp], size);
@@ -119,10 +128,21 @@ s_get_tag_name(Doc* doc, const char* s, int len)
 
 
 
-Node*
-qs_new_tag(Doc* doc) 
+Node *
+qs_new_tag(Doc *doc) 
 {
-  Node* node      = (Node*)apr_palloc(doc->pool, sizeof(Node));
+  Node *node;
+
+  if (! doc) {
+    QX_LOGGER_FATAL("runtime exception: qs_new_tag(): doc is NULL");
+    return NULL;
+  }
+  if (! doc->pool) {
+    QX_LOGGER_FATAL("runtime exception: qs_new_tag(): doc->pool is NULL");
+    return NULL;
+  }
+
+  node = (Node *)apr_palloc(doc->pool, sizeof(Node));
   node->next      = NULL;
   node->parent    = NULL;
   node->child     = NULL;
@@ -138,11 +158,16 @@ qs_new_tag(Doc* doc)
 
 
 
-Node*
-qs_add_attr(Doc* doc, Node* node, Attr* attr) 
+Node *
+qs_add_attr(Doc *doc, Node *node, Attr *attr) 
 {
-  if (node == NULL)
-    QX_LOGGER_FATAL("qs_add_attr() node is null");
+  if (node == NULL) {
+    QX_LOGGER_FATAL("runtime exception: qs_add_attr(): node is null");
+    return NULL;
+  }
+  if (! attr) {
+    return node;
+  }
 
   attr->parent = node;
   attr->next   = NULL;
